@@ -197,8 +197,6 @@ def auth_requires_permission(required_permission, public_table_key=None, public_
             if flask.request.method == 'OPTIONS':
                 return f(*args, **{**kwargs, **{'table_id': table_id}})
 
-            required_level = ['none', 'view', 'edit'].index(required_permission)
-
             table_id_to_dataset = {
                 "pinky100_sv16": "pinky100",
                 "pinky100_neo1": "pinky100",
@@ -223,8 +221,7 @@ def auth_requires_permission(required_permission, public_table_key=None, public_
                 raise Exception("Unknown dataset")
 
             if dataset is not None:
-                level_for_dataset = flask.g.auth_user['permissions'].get(dataset, 0)
-                has_permission = level_for_dataset >= required_level
+                has_permission = required_permission in flask.g.auth_user['permissions_v2'].get(dataset, [])
 
                 if has_permission or flask.g.public_access(): # public_access won't be true for edit requests
                     return f(*args, **{**kwargs, **{'table_id': table_id}})
